# acoutreams

The package `acoutreams` adopts the framework of the `treams` package for acoustic wave scattering in finite and periodic arrangements of particles, based on the T-matrix method.

## Installation

### Installation using pip

To install the package with pip, use

```sh
pip install acoutreams
```
Preliminarily, you have to also install original `treams` as well as `numpy` and `scipy`
```sh
pip install treams
```

## Documentation

The documentation of `treams` can be found at https://tfp-photonics.github.io/treams.

## Publications

When using this code please cite:

## Features

* [x] T-matrix calculations using a spherical or cylindrical wave basis set
* [x] Scattering from clusters of particles
* [x] Scattering from particles and clusters arranged in 3d-, 2d-, and 1d-lattices
* [x] Calculation of sound propagation in stratified media
* [x] Band calculation in crystal structures
